@@ -23,6 +23,7 @@ from monetdb import mapi
 
 logger = logging.getLogger("monetdb")
 
+
 class Cursor(object):
     """This object represents a database cursor, which is used to manage
     the context of a fetch operation. Cursors created from the same
@@ -34,42 +35,40 @@ class Cursor(object):
         object on which the cursor was created."""
         self.connection = connection
 
-        """last executed operation (query)"""
+        # last executed operation (query)
         self.operation = ""
 
-        """This read/write attribute specifies the number of rows to
-        fetch at a time with .fetchmany()"""
+        # This read/write attribute specifies the number of rows to
+        # fetch at a time with .fetchmany()
         self.arraysize = connection.replysize
 
-
-        """This read-only attribute specifies the number of rows that
-        the last .execute*() produced (for DQL statements like
-        'select') or affected (for DML statements like 'update' or
-        'insert').
-
-        The attribute is -1 in case no .execute*() has been
-        performed on the cursor or the rowcount of the last
-        operation is cannot be determined by the interface."""
+        # This read-only attribute specifies the number of rows that
+        # the last .execute*() produced (for DQL statements like
+        # 'select') or affected (for DML statements like 'update' or
+        # 'insert').
+        #
+        # The attribute is -1 in case no .execute*() has been
+        # performed on the cursor or the rowcount of the last
+        # operation is cannot be determined by the interface.
         self.rowcount = -1
 
-        """This read-only attribute is a sequence of 7-item
-        sequences.
-
-        Each of these sequences contains information describing
-        one result column:
-
-          (name,
-           type_code,
-           display_size,
-           internal_size,
-           precision,
-           scale,
-           null_ok)
-
-        This attribute will be None for operations that
-        do not return rows or if the cursor has not had an
-        operation invoked via the .execute*() method yet.
-        """
+        # This read-only attribute is a sequence of 7-item
+        # sequences.
+        #
+        # Each of these sequences contains information describing
+        # one result column:
+        #
+        #   (name,
+        #    type_code,
+        #    display_size,
+        #    internal_size,
+        #    precision,
+        #    scale,
+        #    null_ok)
+        #
+        # This attribute will be None for operations that
+        # do not return rows or if the cursor has not had an
+        # operation invoked via the .execute*() method yet.
         self.description = None
 
         #This read-only attribute indicates at which row
@@ -88,58 +87,36 @@ class Cursor(object):
         #Only select queries have query ID
         self.__query_id = -1
 
-        """This is a Python list object to which the interface appends
-        tuples (exception class, exception value) for all messages
-        which the interfaces receives from the underlying database for
-        this cursor.
-
-        The list is cleared by all standard cursor methods calls (prior
-        to executing the call) except for the .fetch*() calls
-        automatically to avoid excessive memory usage and can also be
-        cleared by executing "del cursor.messages[:]".
-
-        All error and warning messages generated by the database are
-        placed into this list, so checking the list allows the user to
-        verify correct operation of the method calls.
-
-        """
+        # This is a Python list object to which the interface appends
+        # tuples (exception class, exception value) for all messages
+        # which the interfaces receives from the underlying database for
+        # this cursor.
+        #
+        # The list is cleared by all standard cursor methods calls (prior
+        # to executing the call) except for the .fetch*() calls
+        # automatically to avoid excessive memory usage and can also be
+        # cleared by executing "del cursor.messages[:]".
+        #
+        # All error and warning messages generated by the database are
+        # placed into this list, so checking the list allows the user to
+        # verify correct operation of the method calls.
         self.messages = []
 
-
-        """This read-only attribute provides the rowid of the last
-        modified row (most databases return a rowid only when a single
-        INSERT operation is performed). If the operation does not set
-        a rowid or if the database does not support rowids, this
-        attribute should be set to None.
-
-        The semantics of .lastrowid are undefined in case the last
-        executed statement modified more than one row, e.g. when
-        using INSERT with .executemany()."""
+        # This read-only attribute provides the rowid of the last
+        # modified row (most databases return a rowid only when a single
+        # INSERT operation is performed). If the operation does not set
+        # a rowid or if the database does not support rowids, this
+        # attribute should be set to None.
+        #
+        # The semantics of .lastrowid are undefined in case the last
+        # executed statement modified more than one row, e.g. when
+        # using INSERT with .executemany().
         self.lastrowid = None
 
     def __check_executed(self):
         if not self.__executed:
             self.__exception_handler(ProgrammingError, "do a execute() first")
 
-
-    """
-    def callproc(self, procname, parameters=None):
-        (This method is optional since not all databases provide
-        stored procedures. [3])
-
-        Call a stored database procedure with the given name. The
-        sequence of parameters must contain one entry for each
-        argument that the procedure expects. The result of the
-        call is returned as modified copy of the input
-        sequence. Input parameters are left untouched, output and
-        input/output parameters replaced with possibly new values.
-
-        The procedure may also provide a result set as
-        output. This must then be made available through the
-        standard .fetch*() methods.
-    """
-
-
     def close(self):
         """ Close the cursor now (rather than whenever __del__ is
         called).  The cursor will be unusable from this point
@@ -147,7 +124,6 @@ class Cursor(object):
         if any operation is attempted with the cursor."""
         self.connection = None
 
-
     def execute(self, operation, parameters=None):
         """Prepare and execute a database operation (query or
         command).  Parameters may be provided as mapping and
@@ -174,20 +150,21 @@ class Cursor(object):
         else:
             self.operation = operation
 
+        query = ""
         if parameters:
             if isinstance(parameters, dict):
                 query = operation % dict([(k, monetize.convert(v))
-                    for (k,v) in parameters.items()])
+                                         for (k, v) in parameters.items()])
             elif type(parameters) == list or type(parameters) == tuple:
-                query = operation % tuple([monetize.convert(item) for item in parameters])
+                query = operation % tuple([monetize.convert(item) for item
+                                           in parameters])
             elif isinstance(parameters, str):
                 query = operation % monetize.convert(parameters)
             else:
-                self.__exception_handler(ValueError,
-                        "Parameters should be None, dict or list, now it is %s"
-                        % type(parameters))
+                msg = "Parameters should be None, dict or list, now it is %s"
+                self.__exception_handler(ValueError, msg % type(parameters))
         else:
-           query = operation
+            query = operation
 
         block = self.connection.execute(query)
         self.__store_result(block)
@@ -195,8 +172,6 @@ class Cursor(object):
         self.__executed = operation
         return self.rowcount
 
-
-
     def executemany(self, operation, seq_of_parameters):
         """Prepare a database operation (query or command) and then
         execute it against all parameter sequences or mappings
@@ -211,27 +186,19 @@ class Cursor(object):
         self.rowcount = count
         return count
 
-
     def fetchone(self):
         """Fetch the next row of a query result set, returning a
         single sequence, or None when no more data is available."""
-        logger.debug("II executing fetch one")
 
         self.__check_executed()
 
         if self.__query_id == -1:
-            self.__exception_handler(ProgrammingError,
-                    "query didn't result in a resultset")
+            msg = "query didn't result in a resultset"
+            self.__exception_handler(ProgrammingError, msg)
 
-        if self.rownumber >= (self.rowcount):
-            logger.debug("rownumber >= rowcount")
+        if self.rownumber >= self.rowcount:
             return None
 
-        logger.debug("rownumber: %s" % self.rownumber)
-        logger.debug("offset: %s" % self.__offset)
-        logger.debug("lenrows: %s" % len(self.__rows))
-
-
         if self.rownumber >= (self.__offset + len(self.__rows)):
             self.nextset()
 
@@ -239,7 +206,6 @@ class Cursor(object):
         self.rownumber += 1
         return result
 
-
     def fetchmany(self, size=None):
         """Fetch the next set of rows of a query result, returning a
         sequence of sequences (e.g. a list of tuples). An empty
@@ -263,29 +229,24 @@ class Cursor(object):
         parameter is used, then it is best for it to retain the
         same value from one .fetchmany() call to the next."""
 
-        logger.debug("II executing fetchmany")
         self.__check_executed()
 
-        if self.rownumber >= (self.rowcount):
+        if self.rownumber >= self.rowcount:
             return []
 
         end = self.rownumber + (size or self.arraysize)
         end = min(end, self.rowcount)
-
-        logger.debug("end: %s" % end)
-
-        result = self.__rows[self.rownumber - self.__offset:end - self.__offset]
+        result = self.__rows[self.rownumber -
+                             self.__offset:end - self.__offset]
         self.rownumber = min(end, len(self.__rows) + self.__offset)
 
         while (end > self.rownumber) and self.nextset():
-                result += self.__rows[self.rownumber - self.__offset:end -
-                        self.__offset]
+                result += self.__rows[self.rownumber -
+                                      self.__offset:end - self.__offset]
                 self.rownumber = min(end, len(self.__rows) + self.__offset)
         return result
 
-
-
-    def fetchall(self) :
+    def fetchall(self):
         """Fetch all (remaining) rows of a query result, returning
         them as a sequence of sequences (e.g. a list of tuples).
         Note that the cursor's arraysize attribute can affect the
@@ -298,8 +259,8 @@ class Cursor(object):
         self.__check_executed()
 
         if self.__query_id == -1:
-            self.__exception_handler(ProgrammingError,
-                    "query didn't result in a resultset")
+            msg = "query didn't result in a resultset"
+            self.__exception_handler(ProgrammingError, msg)
 
         result = self.__rows[self.rownumber - self.__offset:]
         self.rownumber = len(self.__rows) + self.__offset
@@ -311,8 +272,6 @@ class Cursor(object):
 
         return result
 
-
-
     def nextset(self):
         """This method will make the cursor skip to the next
         available set, discarding any remaining rows from the
@@ -332,29 +291,24 @@ class Cursor(object):
         if self.rownumber >= self.rowcount:
             return False
 
-        logger.debug("retreiving next set")
         self.__offset += len(self.__rows)
 
         end = min(self.rowcount, self.rownumber + self.arraysize)
         amount = end - self.__offset
 
-        command = 'Xexport %s %s %s' % (self.__query_id,
-                self.__offset, amount)
+        command = 'Xexport %s %s %s' % (self.__query_id, self.__offset, amount)
         block = self.connection.command(command)
         self.__store_result(block)
         return True
 
-
     def setinputsizes(self, sizes):
         """
         This method would be used before the .execute*() method
         is invoked to reserve memory. This implementation doesn't
         use this.
-
         """
         pass
 
-
     def setoutputsize(self, size, column=None):
         """
         Set a column buffer size for fetches of large columns
@@ -362,24 +316,26 @@ class Cursor(object):
         """
         pass
 
-
     def __iter__(self):
         return self
 
-
     def next(self):
         row = self.fetchone()
         if not row:
             raise StopIteration
         return row
 
-
     def __store_result(self, block):
         """ parses the mapi result into a resultset"""
 
         if not block:
             block = ""
 
+        column_name = ""
+        scale = display_size = internal_size = precision = 0
+        null_ok = False
+        type_ = []
+
         for line in block.split("\n"):
             if line.startswith(mapi.MSG_INFO):
                 logger.info(line[1:])
@@ -390,11 +346,11 @@ class Cursor(object):
 
                 columns = int(columns)   # number of columns in result
                 self.rowcount = int(rowcount)  # total number of rows
-                tuples = int(tuples)     # number of rows in this set
+                #tuples = int(tuples)     # number of rows in this set
                 self.__rows = []
 
                 # set up fields for description
-                table_name = [None] * columns
+                #table_name = [None] * columns
                 column_name = [None] * columns
                 type_ = [None] * columns
                 display_size = [None] * columns
@@ -402,7 +358,7 @@ class Cursor(object):
                 precision = [None] * columns
                 scale = [None] * columns
                 null_ok = [None] * columns
-                typesizes = [(0, 0)] * columns
+                #typesizes = [(0, 0)] * columns
                 self.__offset = 0
                 self.lastrowid = None
 
@@ -411,14 +367,14 @@ class Cursor(object):
                 values = [x.strip() for x in data.split(",")]
                 identity = identity.strip()
 
-                if identity == "table_name":
-                    table_name = values
-                elif identity == "name":
+                if identity == "name":
                     column_name = values
+                #elif identity == "table_name":
+                #    table_name = values
                 elif identity == "type":
                     type_ = values
-                elif identity == "length":
-                    length = values
+                #elif identity == "length":
+                #   length = values
                 elif identity == "typesizes":
                     typesizes = [[int(j) for j in i.split()] for i in values]
                     internal_size = [x[0] for x in typesizes]
@@ -426,10 +382,10 @@ class Cursor(object):
                         if typeelem in ['decimal']:
                             precision[num] = typesizes[num][0]
                             scale[num] = typesizes[num][1]
-                else:
-                    msg = "unknown header field"
-                    self.messages.append((InterfaceError, msg))
-                    self.__exception_handler(InterfaceError, msg)
+                #else:
+                #    msg = "unknown header field"
+                #    self.messages.append((InterfaceError, msg))
+                #    self.__exception_handler(InterfaceError, msg)
 
                 self.description = list(zip(column_name, type_, display_size,
                                             internal_size, precision, scale,
@@ -437,7 +393,6 @@ class Cursor(object):
                 self.__offset = 0
                 self.lastrowid = None
 
-
             elif line.startswith(mapi.MSG_TUPLE):
                 values = self.__parse_tuple(line)
                 self.__rows .append(values)
@@ -474,23 +429,18 @@ class Cursor(object):
             elif line.startswith(mapi.MSG_ERROR):
                 self.__exception_handler(ProgrammingError, line[1:])
 
-        # you are not supposed to be here
         self.__exception_handler(InterfaceError, "Unknown state, %s" % block)
 
-
     def __parse_tuple(self, line):
         """ parses a mapi data tuple, and returns a list of python types"""
-
-        # values in a row are seperated by \t
         elements = line[1:-1].split(',\t')
         if len(elements) == len(self.description):
-            return tuple([pythonize.convert(element.strip(),
-                description[1]) for (element, description) in
-                zip(elements, self.description)])
+            return tuple([pythonize.convert(element.strip(), description[1])
+                          for (element, description) in zip(elements,
+                                                            self.description)])
         else:
             self.__exception_handler(InterfaceError,
-                    "length of row doesn't match header")
-
+                                     "length of row doesn't match header")
 
     def scroll(self, value, mode='relative'):
         """Scroll the cursor in the result set to a new position according
@@ -506,31 +456,25 @@ class Cursor(object):
         self.__check_executed()
 
         if mode not in ['relative', 'absolute']:
-            self.__exception_handler(ProgrammingError,
-                    "unknown mode '%s'" % mode)
+            msg = "unknown mode '%s'" % mode
+            self.__exception_handler(ProgrammingError, msg)
 
         if mode == 'relative':
-            value = self.rownumber + value
+            value += self.rownumber
 
         if value > self.rowcount:
-             self.__exception_handler(IndexError,
-                     "value beyond length of resultset")
+            self.__exception_handler(IndexError,
+                                     "value beyond length of resultset")
 
         self.__offset = value
         end = min(self.rowcount, self.rownumber + self.arraysize)
         amount = end - self.__offset
-        command = 'Xexport %s %s %s' % (self.__query_id,
-                self.__offset, amount)
+        command = 'Xexport %s %s %s' % (self.__query_id, self.__offset, amount)
         block = self.connection.command(command)
         self.__store_result(block)
 
-
     def __exception_handler(self, exception_class, message):
         """ raises the exception specified by exception, and add the error
         to the message list """
         self.messages.append((exception_class, message))
         raise exception_class(message)
-
-
-
-
